@@ -20,7 +20,6 @@ from __future__ import absolute_import, division, print_function
 import enum
 import hashlib
 import heapq
-import math
 from collections import OrderedDict
 from fractions import Fraction
 
@@ -58,7 +57,6 @@ def combine_labels(*labels):
 
 
 INTEGER_RANGE_DRAW_LABEL = calc_label_from_name("another draw in integer_range()")
-GEOMETRIC_LABEL = calc_label_from_name("geometric()")
 BIASED_COIN_LABEL = calc_label_from_name("biased_coin()")
 SAMPLE_IN_SAMPLER_LABLE = calc_label_from_name("a sample() in Sampler")
 ONE_FROM_MANY_LABEL = calc_label_from_name("one more from many()")
@@ -109,10 +107,6 @@ def integer_range(data, lower, upper, center=None):
     return int(result)
 
 
-def centered_integer_range(data, lower, upper, center):
-    return integer_range(data, lower, upper, center=center)
-
-
 try:
     from numpy import ndarray
 except ImportError:  # pragma: no cover
@@ -131,7 +125,8 @@ def check_sample(values, strategy_name):
                     "to a one-dimensional array, or tuple(values) if you "
                     "want to sample slices.  Sampling a multi-dimensional "
                     "array will be an error in a future version of Hypothesis."
-                ).format(ndim=values.ndim, shape=values.shape)
+                ).format(ndim=values.ndim, shape=values.shape),
+                since="2018-05-09",
             )
     elif not isinstance(values, (OrderedDict, abc.Sequence, enum.EnumMeta)):
         note_deprecation(
@@ -145,7 +140,8 @@ def check_sample(values, strategy_name):
             "handling - and note that when simplifying an example, "
             "Hypothesis treats earlier values as simpler.".format(
                 values=repr(values), strategy=strategy_name
-            )
+            ),
+            since="2017-04-12",
         )
     return tuple(values)
 
@@ -169,18 +165,6 @@ def fractional_float(data):
     return (int_to_float(FLOAT_PREFIX | getrandbits(data, 52)) - 1) / FULL_FLOAT
 
 
-def geometric(data, p):
-    denom = math.log1p(-p)
-    data.start_example(GEOMETRIC_LABEL)
-    while True:
-        probe = fractional_float(data)
-        if probe < 1.0:
-            result = int(math.log1p(-probe) / denom)
-            assert result >= 0, (probe, p, result)
-            data.stop_example()
-            return result
-
-
 def boolean(data):
     return bool(data.draw_bits(1))
 
